@@ -37,6 +37,8 @@ class QScreen;
 class LXQtPanel;
 class LXQtPanelApplicationPrivate;
 
+class ILXQtAbstractWMInterface;
+
 /*!
  * \brief The LXQtPanelApplication class inherits from LXQt::Application and
  * is therefore the QApplication that we will create and execute in our
@@ -89,6 +91,8 @@ public:
      */
     bool isPluginSingletonAndRunning(QString const & pluginId) const;
 
+    ILXQtAbstractWMInterface* getWMBackend() const;
+
 public slots:
     /*!
      * \brief Adds a new LXQtPanel which consists of the following steps:
