@@ -4,7 +4,7 @@
 <context>
     <name>LXQtCustomCommand</name>
     <message>
-        <location filename="../lxqtcustomcommand.cpp" line="186"/>
+        <location filename="../lxqtcustomcommand.cpp" line="188"/>
         <source>Error</source>
         <translation>Klaida</translation>
     </message>
@@ -22,125 +22,130 @@
         <translation>Rodymas</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="191"/>
         <source>Use icon from theme or browse file</source>
         <translation>Naudoti piktogramą iš apipavidalinimo arba naršyti failą</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="188"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="84"/>
         <source>Run with &quot;bash -c&quot;</source>
         <translation>Paleisti naudojant „bash -c“</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="42"/>
         <source>Select Font</source>
         <translation>Pasirinkti šriftą</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
         <source>Text</source>
         <translation>Tekstas</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="135"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
         <source>Command</source>
         <translation>Komanda</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="128"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
         <source>Font</source>
         <translation>Šriftas</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="162"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
         <source> px</source>
         <translation> piks.</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
         <source>%1</source>
         <translation>%1</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="221"/>
         <source>Use %1 to display command output</source>
         <translation>Komandos išvesties rodymui naudoti %1</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="145"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
         <source>Icon</source>
         <translation>Piktograma</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="108"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
         <source>Browse</source>
         <translation>Naršyti</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="155"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
         <source>Autorotate when the panel is vertical</source>
         <translation>Automatiškai pasukti, kai skydelis yra vertikalus</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="240"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="74"/>
         <source>echo Configure...</source>
         <translation>echo Konfigūruoti...</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="243"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="77"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="288"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="305"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="322"/>
         <source>Command to run</source>
         <translation>Komanda, kurią paleisti</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="118"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
         <source>Max Width</source>
         <translation>Didžiausias plotis</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="70"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="136"/>
         <source>Repeat command after:</source>
         <translation>Kartoti komandą po:</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="86"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="152"/>
         <source> second(s)</source>
         <translation> sek.</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="250"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="174"/>
         <source>Command outputs an image</source>
         <translation>Komanda išveda paveikslą</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="262"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
+        <source>Tooltip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="272"/>
         <source>Mouse Commands</source>
         <translation>Pelės komandos</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
         <source>Click</source>
         <translation>Spustelėjimas</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="299"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="295"/>
         <source>Wheel Up</source>
         <translation>Ratuku aukštyn</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="309"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="312"/>
         <source>Wheel Down</source>
         <translation>Ratuku žemyn</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
         <source>Select Icon File</source>
         <translation>Pasirinkti piktogramos failą</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
         <source>Images (*.png *.svg *.xpm *.jpg)</source>
         <translation>Paveikslai (*.png *.svg *.xpm *.jpg)</translation>
     </message>
