@@ -4,7 +4,7 @@
 <context>
     <name>LXQtCustomCommand</name>
     <message>
-        <location filename="../lxqtcustomcommand.cpp" line="186"/>
+        <location filename="../lxqtcustomcommand.cpp" line="188"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
@@ -22,125 +22,130 @@
         <translation>Zobraziť</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="191"/>
         <source>Use icon from theme or browse file</source>
         <translation>Použiť ikonu z témy alebo prehliadať súbor</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="188"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="84"/>
         <source>Run with &quot;bash -c&quot;</source>
         <translation>Spustiť s &quot;bash -c&quot;</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="42"/>
         <source>Select Font</source>
         <translation>Vybrať písmo</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
         <source>Text</source>
         <translation>Text</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="135"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
         <source>Command</source>
         <translation>Príkaz</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="128"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
         <source>Font</source>
         <translation>Písmo</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="162"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
         <source> px</source>
         <translation> px</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
         <source>%1</source>
         <translation>%1</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="221"/>
         <source>Use %1 to display command output</source>
         <translation>Použiť%1 na zobrazenie výstupu príkazu</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="145"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
         <source>Icon</source>
         <translation>Ikona</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="108"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
         <source>Browse</source>
         <translation>Prehliadať</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="155"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
         <source>Autorotate when the panel is vertical</source>
         <translation>Automaticky otočiť v prípade, že je panel zvislý</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="240"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="74"/>
         <source>echo Configure...</source>
         <translation>echo Konfigurovať...</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="243"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="77"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="288"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="305"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="322"/>
         <source>Command to run</source>
         <translation>Príkaz na spustenie</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="118"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
         <source>Max Width</source>
         <translation>Maximálna šírka</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="70"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="136"/>
         <source>Repeat command after:</source>
         <translation>Opakovať príkaz po:</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="86"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="152"/>
         <source> second(s)</source>
         <translation> Sekundy(s)</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="250"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="174"/>
         <source>Command outputs an image</source>
         <translation>Príkaz vygeneruje obrázok</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="262"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
+        <source>Tooltip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="272"/>
         <source>Mouse Commands</source>
         <translation>Príkaz myšou</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
         <source>Click</source>
         <translation>Kliknutie</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="299"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="295"/>
         <source>Wheel Up</source>
         <translation>Koliesko hore</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.ui" line="309"/>
+        <location filename="../lxqtcustomcommandconfiguration.ui" line="312"/>
         <source>Wheel Down</source>
         <translation>Koliesko dole</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
         <source>Select Icon File</source>
         <translation>Vybrať súbor ikôn</translation>
     </message>
     <message>
-        <location filename="../lxqtcustomcommandconfiguration.cpp" line="147"/>
+        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
         <source>Images (*.png *.svg *.xpm *.jpg)</source>
         <translation>Obrázky (*.png *.svg *.xpm *.jpg)</translation>
     </message>
