@@ -4,13 +4,13 @@
 <context>
     <name>DesktopSwitch</name>
     <message>
-        <location filename="../desktopswitch.cpp" line="99"/>
+        <location filename="../desktopswitch.cpp" line="95"/>
         <source>Switch to desktop %1</source>
         <translation>Премини към плот %1</translation>
     </message>
     <message>
-        <location filename="../desktopswitch.cpp" line="160"/>
-        <location filename="../desktopswitch.cpp" line="171"/>
+        <location filename="../desktopswitch.cpp" line="170"/>
+        <location filename="../desktopswitch.cpp" line="181"/>
         <source>Desktop %1</source>
         <translation>Плот %1</translation>
     </message>
@@ -19,7 +19,7 @@
     <name>DesktopSwitchConfiguration</name>
     <message>
         <location filename="../desktopswitchconfiguration.ui" line="14"/>
-        <source>DesktopSwitch settings</source>
+        <source>DesktopSwitch Settings</source>
         <translation>Настройки за превключване на плота</translation>
     </message>
     <message>
@@ -68,7 +68,7 @@
         <translation>Име на плот</translation>
     </message>
     <message>
-        <location filename="../desktopswitchconfiguration.cpp" line="71"/>
+        <location filename="../desktopswitchconfiguration.cpp" line="78"/>
         <source>Desktop %1:</source>
         <translation>Плот %1:</translation>
     </message>
@@ -76,12 +76,12 @@
 <context>
     <name>DesktopSwitchUnsupported</name>
     <message>
-        <location filename="../desktopswitch.h" line="111"/>
+        <location filename="../desktopswitch.cpp" line="342"/>
         <source>n/a</source>
         <translation>n/a</translation>
     </message>
     <message>
-        <location filename="../desktopswitch.h" line="113"/>
+        <location filename="../desktopswitch.cpp" line="344"/>
         <source>DesktopSwitch is unsupported on current platform: %1</source>
         <translation>DesktopSwitch не се поддържа на текущата платформа: %1</translation>
     </message>
