@@ -5,7 +5,7 @@
     <name>TreeWindow</name>
     <message>
         <location filename="../treewindow.ui" line="14"/>
-        <source>Panel DOM tree</source>
+        <source>Panel DOM Tree</source>
         <translation>ਪੈਨਲ DOM ਲੜੀ</translation>
     </message>
     <message>
