@@ -38,7 +38,7 @@ class LXQtNetworkMonitor: public QFrame
 {
     Q_OBJECT
 public:
-    LXQtNetworkMonitor(ILXQtPanelPlugin *plugin, QWidget* parent = 0);
+    LXQtNetworkMonitor(ILXQtPanelPlugin *plugin, QWidget* parent = nullptr);
     ~LXQtNetworkMonitor();
     virtual void settingsChanged();
 
@@ -53,7 +53,7 @@ private:
     static QString convertUnits(double num);
     QString iconName(const QString& state) const
     {
-        return QString(":/images/knemo-%1-%2.png")
+        return QStringLiteral(":/images/knemo-%1-%2.png")
                .arg(m_iconList[m_iconIndex], state);
     }
 
