@@ -9,48 +9,53 @@
         <translation>Nastavení oznamování stavu</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="28"/>
-        <location filename="../statusnotifierconfiguration.ui" line="38"/>
+        <location filename="../statusnotifierconfiguration.ui" line="25"/>
+        <source>Reverse the order of items</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../statusnotifierconfiguration.ui" line="39"/>
+        <location filename="../statusnotifierconfiguration.ui" line="49"/>
         <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
         <translation>Automaticky skrývaná položka zůstane po tuto dobu viditelná, pokud položka vyžaduje pozornost.</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="31"/>
+        <location filename="../statusnotifierconfiguration.ui" line="42"/>
         <source>Attention period:</source>
         <translation>Doba pozornosti:</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="41"/>
+        <location filename="../statusnotifierconfiguration.ui" line="52"/>
         <source> minute(s)</source>
         <translation> minut(a)</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="72"/>
+        <location filename="../statusnotifierconfiguration.ui" line="83"/>
         <source>Change visibility of items</source>
         <translation>Změnit viditelnost položek</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="85"/>
+        <location filename="../statusnotifierconfiguration.ui" line="96"/>
         <source>Item</source>
         <translation>Položka</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.ui" line="90"/>
+        <location filename="../statusnotifierconfiguration.ui" line="101"/>
         <source>Visibility</source>
         <translation>Viditelnost</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
+        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
         <source>Always show</source>
         <translation>Ukázat vždy</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
+        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
         <source>Auto-hide</source>
         <translation>Automaticky skrývat</translation>
     </message>
     <message>
-        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
+        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
         <source>Always hide</source>
         <translation>Skrýt vždy</translation>
     </message>
