@@ -4,7 +4,7 @@
 <context>
     <name>LXQtTaskBar</name>
     <message>
-        <location filename="../lxqttaskbar.cpp" line="636"/>
+        <location filename="../lxqttaskbar.cpp" line="649"/>
         <source>Activate task %1</source>
         <translation>Activate task %1</translation>
     </message>
@@ -29,47 +29,47 @@
     <message>
         <location filename="../lxqttaskbutton.cpp" line="593"/>
         <source>Desktop &amp;%1</source>
-        <translation type="unfinished"></translation>
+        <translation>Desktop &amp;%1</translation>
     </message>
     <message>
         <location filename="../lxqttaskbutton.cpp" line="603"/>
         <source>&amp;To Current Desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;To Current Desktop</translation>
     </message>
     <message>
         <location filename="../lxqttaskbutton.cpp" line="612"/>
         <source>Move To N&amp;ext Monitor</source>
-        <translation type="unfinished"></translation>
+        <translation>Move To N&amp;ext Monitor</translation>
     </message>
     <message>
         <location filename="../lxqttaskbutton.cpp" line="618"/>
         <source>Move To &amp;Previous Monitor</source>
-        <translation type="unfinished"></translation>
+        <translation>Move To &amp;Previous Monitor</translation>
     </message>
     <message>
         <location filename="../lxqttaskbutton.cpp" line="624"/>
         <source>&amp;Move</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Move</translation>
     </message>
     <message>
         <location filename="../lxqttaskbutton.cpp" line="629"/>
         <source>Resi&amp;ze</source>
-        <translation type="unfinished"></translation>
+        <translation>Resi&amp;ze</translation>
     </message>
     <message>
         <location filename="../lxqttaskbutton.cpp" line="638"/>
         <source>Ma&amp;ximize</source>
-        <translation type="unfinished"></translation>
+        <translation>Ma&amp;ximise</translation>
     </message>
     <message>
         <location filename="../lxqttaskbutton.cpp" line="647"/>
         <source>Maximize vertically</source>
-        <translation type="unfinished"></translation>
+        <translation>Maximise vertically</translation>
     </message>
     <message>
         <location filename="../lxqttaskbutton.cpp" line="654"/>
         <source>Maximize horizontally</source>
-        <translation type="unfinished"></translation>
+        <translation>Maximise horizontally</translation>
     </message>
     <message>
         <location filename="../lxqttaskbutton.cpp" line="662"/>
@@ -167,6 +167,17 @@
         <source>Close on middle-click</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="254"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="264"/>
+        <source>Comma separated list of window classes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="257"/>
+        <source>Exclude from taskbar</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
         <source>Cycle windows on wheel scrolling</source>
