@@ -79,7 +79,7 @@ private:
     GlobalKeyShortcut::Action *m_keyMuteToggle;
     LXQt::Notification *m_notification;
     QPointer<LXQtVolumeConfiguration> m_configDialog;
-    bool m_allwaysShowNotifications;
+    bool m_alwaysShowNotifications;
     bool m_showKeyboardNotifications;
 };
 
