@@ -36,7 +36,6 @@
 #include <QPushButton>
 #include <QVBoxLayout>
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QToolTip>
 #include "audioengine.h"
 #include <QDebug>
@@ -75,7 +74,7 @@ VolumePopup::VolumePopup(QWidget* parent):
 
     QVBoxLayout *l = new QVBoxLayout(this);
     l->setSpacing(0);
-    l->setMargin(0);
+    l->setContentsMargins(QMargins());
 
     l->addWidget(m_mixerButton, 0, Qt::AlignHCenter);
     l->addWidget(m_volumeSlider, 0, Qt::AlignHCenter);
@@ -110,7 +109,7 @@ bool VolumePopup::eventFilter(QObject * watched, QEvent * event)
     return QDialog::eventFilter(watched, event);
 }
 
-void VolumePopup::enterEvent(QEvent * /*event*/)
+void VolumePopup::enterEvent(QEnterEvent * /*event*/)
 {
     emit mouseEntered();
 }
